Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(505)

Unified Diff: third_party/WebKit/Source/core/layout/svg/SVGLayoutSupport.cpp

Issue 1911473002: Rename transformToRoot:ish names to screenScaleFactorChanged:ish ones (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@svg-hiddencontainer-layout-no-xfrmchg
Patch Set: Update comment in LayoutSVGText. Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/core/layout/svg/SVGLayoutSupport.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/core/layout/svg/SVGLayoutSupport.cpp
diff --git a/third_party/WebKit/Source/core/layout/svg/SVGLayoutSupport.cpp b/third_party/WebKit/Source/core/layout/svg/SVGLayoutSupport.cpp
index 08b155564567a8716bc1c0b2f7617bea4c9cd4de..b5681822dd7a04521e2faf5719d1af9a1c0e5771 100644
--- a/third_party/WebKit/Source/core/layout/svg/SVGLayoutSupport.cpp
+++ b/third_party/WebKit/Source/core/layout/svg/SVGLayoutSupport.cpp
@@ -259,25 +259,27 @@ bool SVGLayoutSupport::layoutSizeOfNearestViewportChanged(const LayoutObject* st
return false;
}
-bool SVGLayoutSupport::transformToRootChanged(const LayoutObject* ancestor)
+bool SVGLayoutSupport::screenScaleFactorChanged(const LayoutObject* ancestor)
{
while (ancestor && !ancestor->isSVGRoot()) {
if (ancestor->isSVGTransformableContainer())
- return toLayoutSVGTransformableContainer(ancestor)->didTransformToRootUpdate();
+ return toLayoutSVGTransformableContainer(ancestor)->didScreenScaleFactorChange();
if (ancestor->isSVGViewportContainer())
- return toLayoutSVGViewportContainer(ancestor)->didTransformToRootUpdate();
+ return toLayoutSVGViewportContainer(ancestor)->didScreenScaleFactorChange();
ancestor = ancestor->parent();
}
return false;
}
-void SVGLayoutSupport::layoutChildren(LayoutObject* firstChild, bool forceLayout, bool transformChanged, bool layoutSizeChanged)
+void SVGLayoutSupport::layoutChildren(
+ LayoutObject* firstChild, bool forceLayout, bool screenScalingFactorChanged, bool layoutSizeChanged)
{
for (LayoutObject* child = firstChild; child; child = child->nextSibling()) {
bool forceChildLayout = forceLayout;
- if (transformChanged) {
- // If the transform changed we need to update the text metrics (note: this also happens for layoutSizeChanged=true).
+ if (screenScalingFactorChanged) {
+ // If the screen scaling factor changed we need to update the text
+ // metrics (note: this also happens for layoutSizeChanged=true).
if (child->isSVGText())
toLayoutSVGText(child)->setNeedsTextMetricsUpdate();
forceChildLayout = true;
« no previous file with comments | « third_party/WebKit/Source/core/layout/svg/SVGLayoutSupport.h ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698